#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-parser
version:              0.2.7.0
visibility:           public
id:                   ghc-parser-0.2.7.0-BRTFlaUrolQBsJaOfBXbID
key:                  ghc-parser-0.2.7.0-BRTFlaUrolQBsJaOfBXbID
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             https://github.com/IHaskell/IHaskell
synopsis:             Haskell source parser from GHC.
category:             Language
abi:                  c3d3a467d6f7c227662099961c126ec6
exposed:              True
exposed-modules:
    Language.Haskell.GHC.HappyParser Language.Haskell.GHC.Parser

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghc-parser-0.2.7.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghc-parser-0.2.7.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghc-parser-0.2.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-parser
hs-libraries:         HSghc-parser-0.2.7.0-BRTFlaUrolQBsJaOfBXbID
depends:              base-4.18.2.1 ghc-9.6.6
haddock-interfaces:   /usr/share/doc/haskell-ghc-parser/html/ghc-parser.haddock
haddock-html:         /usr/share/doc/haskell-ghc-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

